@@ -2,7 +2,7 @@
 #  nested.py
 #  Copyright, 2007 - Paul McGuire
 #
-#  Simple example of using nestedExpr to define expressions using
+#  Simple example of using nested_expr to define expressions using
 #  paired delimiters for grouping lists and sublists
 #
 
@@ -20,9 +20,9 @@ data = """
 """
 
 # use {}'s for nested lists
-nestedItems = nestedExpr("{", "}")
-print((nestedItems + stringEnd).parseString(data).asList())
+nestedItems = nested_expr("{", "}")
+print((nestedItems + string_end).parse_string(data).as_list())
 
 # use default delimiters of ()'s
-mathExpr = nestedExpr()
-print(mathExpr.parseString("((( ax + by)*C) *(Z | (E^F) & D))"))
+mathExpr = nested_expr()
+print(mathExpr.parse_string("((( ax + by)*C) *(Z | (E^F) & D))"))
